@@ -867,6 +867,7 @@ class AWSpider:
             self.peers[ uuid ] = {}
         self.peers[ uuid ]["local_ip"] = local_ip
         self.peers[ uuid ]["port"] = port
+        self.peers[ uuid ]["uri"] = "http://%s:%s" % (local_ip, port )
     
     def _verifyPeerPublicIPCallback( self, data, uuid, public_ip, port ):
         logger.debug( "Verified public IP for %s" % uuid )
@@ -874,4 +875,5 @@ class AWSpider:
             self.peers[ uuid ] = {}
         self.peers[ uuid ]["public_ip"] = public_ip
         self.peers[ uuid ]["port"] = port
+        self.peers[ uuid ]["uri"] = "http://%s:%s" % (public_ip, port )
         
